==> qore-0.9.4.5.tar.bz2: qore-0.9.4.5/docs/modules/TableMapper/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TableMapper Module Reference", "index.html", [
    [ "TableMapper Module", "index.html", [
      [ "TableMapper Module Introduction", "index.html#tablemapperintro", null ],
      [ "Inserting Sequence Values with the InboundTableMapper Class", "index.html#inboundtablemapper_sequences", null ],
      [ "TableMapper Examples", "index.html#tablemapperexamples", null ],
      [ "InboundTableMapper Bulk Insert API", "index.html#tablemapper_bulk_insert_api", [
        [ "InboundTableMapper Bulk Insert API Introduction", "index.html#tablemapper_bulk_insert_api_intro", null ],
        [ "InboundTableMapper Bulk Insert API Usage", "index.html#tablemapper_bulk_insert_api_usage", null ],
        [ "InboundTableMapper Bulk Insert API Examples", "index.html#tablemapper_bulk_insert_api_examples", null ]
      ] ],
      [ "TableMapper Specification Format", "index.html#tablemapperkeys", null ],
      [ "Release Notes", "index.html#tablemapperrelnotes", [
        [ "TableMapper v1.3", "index.html#tablemapperv1_3", null ],
        [ "TableMapper v1.2.2", "index.html#tablemapperv1_2_2", null ],
        [ "TableMapper v1.2.1", "index.html#tablemapperv1_2_1", null ],
        [ "TableMapper v1.2", "index.html#tablemapperv1_2", null ],
        [ "TableMapper v1.1.4", "index.html#tablemapperv1_1_4", null ],
        [ "TableMapper v1.1.3", "index.html#tablemapperv1_1_3", null ],
        [ "TableMapper v1.1.2", "index.html#tablemapperv1_1_2", null ],
        [ "TableMapper v1.1.1", "index.html#tablemapperv1_1_1", null ],
        [ "TableMapper v1.1", "index.html#tablemapperv1_1", null ],
        [ "TableMapper v1.0", "index.html#tablemapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.0.3.tar.bz2: qore-1.0.3/docs/modules/TableMapper/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore TableMapper Module Reference", "index.html", [
    [ "TableMapper Module", "index.html", [
      [ "TableMapper Module Introduction", "index.html#tablemapperintro", null ],
      [ "Inserting Sequence Values with the InboundTableMapper Class", "index.html#inboundtablemapper_sequences", null ],
      [ "TableMapper Examples", "index.html#tablemapperexamples", null ],
      [ "InboundTableMapper Bulk Insert API", "index.html#tablemapper_bulk_insert_api", [
        [ "InboundTableMapper Bulk Insert API Introduction", "index.html#tablemapper_bulk_insert_api_intro", null ],
        [ "InboundTableMapper Bulk Insert API Usage", "index.html#tablemapper_bulk_insert_api_usage", null ],
        [ "InboundTableMapper Bulk Insert API Examples", "index.html#tablemapper_bulk_insert_api_examples", null ]
      ] ],
      [ "TableMapper Specification Format", "index.html#tablemapperkeys", null ],
      [ "Release Notes", "index.html#tablemapperrelnotes", [
        [ "TableMapper v1.3", "index.html#tablemapperv1_3", null ],
        [ "TableMapper v1.2.2", "index.html#tablemapperv1_2_2", null ],
        [ "TableMapper v1.2.1", "index.html#tablemapperv1_2_1", null ],
        [ "TableMapper v1.2", "index.html#tablemapperv1_2", null ],
        [ "TableMapper v1.1.4", "index.html#tablemapperv1_1_4", null ],
        [ "TableMapper v1.1.3", "index.html#tablemapperv1_1_3", null ],
        [ "TableMapper v1.1.2", "index.html#tablemapperv1_1_2", null ],
        [ "TableMapper v1.1.1", "index.html#tablemapperv1_1_1", null ],
        [ "TableMapper v1.1", "index.html#tablemapperv1_1", null ],
        [ "TableMapper v1.0", "index.html#tablemapperv1_0", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
